##############################################################################
#
# Copyright (C) Zenoss, Inc. 2013, all rights reserved.
#
# This content is made available according to terms specified in
# License.zenoss under the directory where your Zenoss product is installed.
#
##############################################################################

XML_NS_SOAP_1_2 = 'http://www.w3.org/2003/05/soap-envelope'
XML_NS_CIM_SCHEMA = "http://schemas.dmtf.org/wbem/wscim/1/common"
XML_NS_WS_MAN = 'http://schemas.dmtf.org/wbem/wsman/1/wsman.xsd'
XML_NS_ENUMERATION = 'http://schemas.xmlsoap.org/ws/2004/09/enumeration'
XML_NS_EVENTING = 'http://schemas.xmlsoap.org/ws/2004/08/eventing'
XML_NS_BUILTIN = 'http://www.w3.org/2001/XMLSchema-instance'
XML_NS_MSWSMAN = 'http://schemas.microsoft.com/wbem/wsman/1/wsman.xsd'
XML_NS_MSRSP = 'http://schemas.microsoft.com/wbem/wsman/1/windows/shell'
XML_NS_MSEVENT = 'http://schemas.microsoft.com/win/2004/08/events/event'

SOAP_HEADER = 'Header'
SOAP_BODY = 'Body'
BUILTIN_NIL = 'nil'
WSM_XML_FRAGMENT = 'XmlFragment'
WSENUM_ENUMERATION_CONTEXT = 'EnumerationContext'
WSENUM_END_OF_SEQUENCE = 'EndOfSequence'
WSENUM_ITEMS = 'Items'

WMICIMV2 = 'http://schemas.microsoft.com/wbem/wsman/1/wmi/root/cimv2'

SHELL_SIGNAL_TERMINATE = \
    'http://schemas.microsoft.com/wbem/wsman/1/windows/shell/signal/terminate'
SHELL_SIGNAL_CTRL_C = \
    'http://schemas.microsoft.com/wbem/wsman/1/windows/shell/signal/ctrl_c'
